@@ -101,5 +101,8 @@ LIMITEXCEEDED_TOOLARGEFILEERROR = 'LimitExceeded.TooLargeFileError'
 # 发票不存在。
 RESOURCENOTFOUND_NOINVOICE = 'ResourceNotFound.NoInvoice'
 
+# 不支持当天发票查询。
+RESOURCENOTFOUND_NOTSUPPORTCURRENTINVOICEQUERY = 'ResourceNotFound.NotSupportCurrentInvoiceQuery'
+
 # 计费状态异常。
 RESOURCESSOLDOUT_CHARGESTATUSEXCEPTION = 'ResourcesSoldOut.ChargeStatusException'
